![FiQuS logo](docs/images/FiQuS_name_logo.svg)

# Introduction
Source code for STEAM **FiQuS** (**Fi**nite Element Method **Qu**ench **S**imulation) tool.

# Folder Structure
![FiQuS folder structure](docs/images/FiQuS_folder_structure.svg)

# Installation

## Released version:
```pip install fiqus```

## Test version:
```pip install -i https://test.pypi.org/simple/fiqus```

# Links
STEAM website: https://espace.cern.ch/steam/

STEAM-FiQuS website: https://espace.cern.ch/steam/SitePages/FiQuS.aspx

STEAM-FiQuS documentation: https://steam-fiqus.docs.cern.ch/ 

Coverage report: https://steam-fiqus.docs.cern.ch/htmlcov/ 

# Contact
steam-team@cern.ch

# STEAM User Agreement
By using any software of the STEAM framework, users agree with this document:
https://edms.cern.ch/document/2024516

(Copyright © 2022, CERN, Switzerland. All rights reserved.)
